@@ -5,6 +5,8 @@ extern crate robotparser_fork;
 extern crate scraper;
 extern crate tokio;
 extern crate url;
+extern crate hashbrown;
+extern crate log;
 
 /// Configuration structure for `Website`
 pub mod configuration;
